@@ -29,29 +29,32 @@ MIGHAgEAMBMGByqGSM49AgEGCCqGSM49AwEHBG0wawIBAQQgAfMysADImEAjdKcY
 oiFLpikvU6LFOTCI0DsJFT+28bCWB2RUk+FAuEqV0FGTftyjzMu/edqz
 -----END PRIVATE KEY-----"""
 
-def fetch_sender(id: str) -> RemoteUser:
+
+def fetch_user(id: str) -> RemoteUser:
     """
     Resolve id to RemoteUser object.
     Usually this function requests your API to fetch user keys.
     """
     if id == "monitor":
-        return UserManagement.importRemoteUser("monitor", pub_A, pub_A, pub_ca)
+        return UserManagement.importRemoteUser("monitor", pub_A, pub_A, True, pub_ca)
+    raise Exception("User not found")
+
 
 # This code initializes the it-crypto library with the private key pub_A and secret key priv_A.
-it_crypto = ItCrypto(fetch_sender)
+it_crypto = ItCrypto(fetch_user)
 it_crypto.login("monitor", pub_A, pub_A, priv_A, priv_A)
 
 # The logged-in user can create singed access logs.
-log = AccessLog(it_crypto.user.id, "owner", "tool", "just", 1234, "kind", ["data", "datat more"])
-signed_log = it_crypto.sign_access_log(log)
+log = AccessLog("monitor", "owner", "tool", "just", 1234, "kind", ["data", "datat more"])
+signed_log = it_crypto.sign_log(log)
 
 # The logged-in user can encrypt the logs for others.
 owner = UserManagement.generateAuthenticatedUser("owner")
-jwe = it_crypto.encrypt(signed_log, [owner])
+jwe = it_crypto.encrypt_log(signed_log, [owner])
 
 # The logged-in user can decrypt logs intended for him
 it_crypto.user = owner
-received_signed_log = it_crypto.decrypt(jwe)
+received_signed_log = it_crypto.decrypt_log(jwe)
 received_log = received_signed_log.extract()
 print(received_log)
 
