@@ -1,8 +1,11 @@
-from logs.serializable import Serializable
-from utils import b64decode
+from py_it_crypto.logs.serializable import Serializable
+from py_it_crypto.utils import b64decode
 
 
 class AccessLog(Serializable):
+    """
+    Represents a raw AccessLog, which is not signed by a monitor.
+    """
     def __init__(self, monitor: str, owner: str, tool: str, justification: str, timestamp: int,
                  accessKind: str,
                  dataType: list[str]):
@@ -19,16 +22,6 @@ class AccessLog(Serializable):
         return AccessLog("monitor", "owner", "tool", "just", 1234, "kind", ["data", "datat more"])
 
     @staticmethod
-    def from_signed_log(log: 'SignedAccessLog') -> 'AccessLog':
+    def from_signed_log(log) -> 'AccessLog':
         data = b64decode(log.payload)
-        return AccessLog.from_json(data.decode())
-
-
-class SignedAccessLog(Serializable):
-    def __init__(self, payload: str, protected: str, signature: str):
-        self.payload = payload
-        self.protected = protected
-        self.signature = signature
-
-    def extract(self) -> AccessLog:
-        return AccessLog.from_signed_log(self)
+        return AccessLog.from_json(data.decode())
\ No newline at end of file
