@@ -1,3 +1,6 @@
+import base64
+import cProfile
+import json
 from unittest import TestCase
 
 from py_it_crypto.logs.access_log import AccessLog
@@ -18,9 +21,10 @@ class TestUser(TestCase):
         access_log.owner = receiver.id
         access_log.monitor = sender.id
 
-        signed_log = sender.sign_access_log(access_log)
-        cipher = sender.encrypt(signed_log,[receiver])
-        received_signed_log = receiver.decrypt(cipher, fetch_user)
+        sender.is_monitor = True
+        signed_log = sender.sign_log(access_log)
+        cipher = sender.encrypt_log(signed_log, [receiver])
+        received_signed_log = receiver.decrypt_log(cipher, fetch_user)
 
         verify_access_logs(access_log, received_signed_log.extract())
 
@@ -39,18 +43,19 @@ class TestUser(TestCase):
         access_log.owner = owner.id
         access_log.monitor = monitor.id
 
-        signed_log = monitor.sign_access_log(access_log)
-        cipher = monitor.encrypt(signed_log, [owner])
+        monitor.is_monitor = True
+        signed_log = monitor.sign_log(access_log)
+        cipher = monitor.encrypt_log(signed_log, [owner])
 
         # 2. Step: Owner can decrypt log
-        received_signed_log1 = owner.decrypt(cipher, fetch_user)
+        received_signed_log1 = owner.decrypt_log(cipher, fetch_user)
 
         # 3. Step: Owner shares with receiver
-        cipher = owner.encrypt(signed_log, [owner, receiver])
+        cipher = owner.encrypt_log(signed_log, [owner, receiver])
 
         # 4. Step: Owner and receiver can decrypt
-        received_signed_log2 = owner.decrypt(cipher, fetch_user)
-        received_signed_log3 = receiver.decrypt(cipher, fetch_user)
+        received_signed_log2 = owner.decrypt_log(cipher, fetch_user)
+        received_signed_log3 = receiver.decrypt_log(cipher, fetch_user)
 
         verify_access_logs(access_log, received_signed_log1.extract())
         verify_access_logs(received_signed_log1.extract(), received_signed_log2.extract())
@@ -66,29 +71,30 @@ class TestUser(TestCase):
         access_log.owner = receiver.id
         access_log.monitor = sender.id
 
-        signed_log = sender.sign_access_log(access_log)
-        cipher = sender.encrypt(signed_log, [receiver])
-        received_signed_log = receiver.decrypt(cipher, fetch_user)
+        sender.is_monitor = True
+        signed_log = sender.sign_log(access_log)
+        cipher = sender.encrypt_log(signed_log, [receiver])
+        received_signed_log = receiver.decrypt_log(cipher, fetch_user)
 
         verify_access_logs(access_log, received_signed_log.extract())
 
     def test_import_user_signed(self):
         """Import users with CA signed keys"""
         sender = UserManagement.importAuthenticatedUser('sender', pub_A, pub_A, priv_A, priv_A)
-        receiver = UserManagement.importRemoteUser('receiver', pub_B, pub_B, pub_ca)
+        receiver = UserManagement.importRemoteUser('receiver', pub_B, pub_B, False, pub_ca)
         fetch_user = create_fetch_sender([sender])
 
         access_log = AccessLog.generate()
         access_log.owner = receiver.id
         access_log.monitor = sender.id
 
-        signed_log = sender.sign_access_log(access_log)
-        cipher = sender.encrypt(signed_log, [receiver])
+        signed_log = sender.sign_log(access_log)
+        cipher = sender.encrypt_log(signed_log, [receiver])
 
     def test_import_user_signed_fails(self):
         """Import users with CA signed keys fails"""
         sender = UserManagement.importAuthenticatedUser('sender', pub_A, pub_A, priv_A, priv_A)
 
         with self.assertRaises(Exception) as context:
-            UserManagement.importRemoteUser('receiver', pub_B, pub_B, invalid_pub_ca)
+            UserManagement.importRemoteUser('receiver', pub_B, pub_B, False, invalid_pub_ca)
         self.assertTrue('Could not verify encryption certificate' in str(context.exception))
